TextRecognitionCamera class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TextRecognitionCamera
Constructors
- TextRecognitionCamera({Key? key, required String title, required String pattern, String notFoundMessage = 'No se encontró el patrón en el texto', String successMessage = 'Texto reconocido:', double width = 400, double height = 600, Color backgroundColor = Colors.white, Color primaryColor = Colors.blue, Color successColor = Colors.green, Color errorColor = Colors.red, String? initialImagePath, Color? textColor, Color? secondaryTextColor, Color? buttonBackgroundColor, Color? buttonForegroundColor, Color? containerBackgroundColor, Color? buttonAcceptForegroundColor, int maxImageWidth = 1920, int maxImageHeight = 1080, int imageQuality = 85, int maxImageDimension = 4000})
-
const
Properties
- backgroundColor → Color
-
final
-
final
-
final
-
final
- containerBackgroundColor → Color?
-
final
- errorColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- imageQuality → int
-
Calidad de la imagen (0-100, por defecto 85)
final
- initialImagePath → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxImageDimension → int
-
Dimensión máxima antes de escalar (por defecto 4000)
final
- maxImageHeight → int
-
Alto máximo para la imagen comprimida (por defecto 1080)
final
- maxImageWidth → int
-
Ancho máximo para la imagen comprimida (por defecto 1920)
final
- notFoundMessage → String
-
final
- pattern → String
-
final
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryTextColor → Color?
-
final
- successColor → Color
-
final
- successMessage → String
-
final
- textColor → Color?
-
final
- title → String
-
final
- width → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TextRecognitionCamera> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited